==> 0.0.5.tar.gz: lib/hyperkyc_face_match_data.dart <==
import 'dart:convert';

import 'package:hyperkyc_flutter/hyperkyc_api_base_response.dart';

import 'hyperkyc_flutter_constants.dart';

/// FaceMatchDataResult contains FaceMatchData
class FaceMatchDataResult {
  /// tag of document for which this faceMatch result belongs to
  final String? tag;

  /// documentId for which this faceMatch result belongs to
  final String? documentId;

  /// List of document capture and OCR results based on no. of sides of the selected document
  final FaceMatchData? faceMatchData;

  /// Constructor
  FaceMatchDataResult({
    this.tag,
    this.documentId,
    this.faceMatchData,
  });

  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.tag: this.tag,
      HyperKycConstants.documentId: this.documentId,
      HyperKycConstants.faceMatchData: this.faceMatchData,
    };
  }

  factory FaceMatchDataResult.fromMap(Map<dynamic, dynamic> map) {
    return FaceMatchDataResult(
      tag: map[HyperKycConstants.tag] as String?,
      documentId: map[HyperKycConstants.documentId] as String?,
      faceMatchData:
          FaceMatchData.fromMap(map[HyperKycConstants.faceMatchData] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FaceMatchDataResult{tag: $tag, documentId: $documentId, faceMatchData: $faceMatchData}';
  }
}

/// FaceMatchData contains face match result
class FaceMatchData {
  /// Action - pass / manualReview / fail
  final String? action;

  /// Response headers (json string) from face match API
  final String? responseHeaders;

  /// Response body from the face match API
  final FaceMatchApiDetail? responseResult;

  /// Constructor
  FaceMatchData({
    this.action,
    this.responseHeaders,
    this.responseResult,
  });

  /// Convert FaceMatchData object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.action: this.action,
      HyperKycConstants.responseHeaders: this.responseHeaders,
      HyperKycConstants.responseResult: this.responseResult,
    };
  }

  /// Convert Map to FaceMatchData object
  factory FaceMatchData.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return FaceMatchData();
    }
    return FaceMatchData(
      action: map[HyperKycConstants.action] as String?,
      responseHeaders: map[HyperKycConstants.responseHeaders] as String?,
      responseResult: FaceMatchApiDetail.fromMap(
          jsonDecode(map[HyperKycConstants.responseResult]) ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FaceMatchData{action: $action, responseHeaders: $responseHeaders, responseResult: $responseResult}';
  }
}

/// FaceMatchApiDetail is response body from the Hyperverge face match API call
class FaceMatchApiDetail {
  /// Metadata contains data like TransactionId, RequestId, Attempts count, etc
  final Metadata? metadata;

  /// Status received after Hyperverge API call
  final String? status;

  /// StatusCode received after Hyperverge API call
  final String? statusCode;

  /// FaceMatchResult
  final FaceMatchResult? result;

  /// Constructor
  FaceMatchApiDetail({
    this.metadata,
    this.status,
    this.statusCode,
    this.result,
  });

  /// Convert FaceMatchApiDetail object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.metadata: this.metadata,
      HyperKycConstants.status: this.status,
      HyperKycConstants.statusCode: this.statusCode,
      HyperKycConstants.result: this.result,
    };
  }

  /// Convert Map to FaceMatchApiDetail object
  factory FaceMatchApiDetail.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return FaceMatchApiDetail();
    }
    return FaceMatchApiDetail(
      metadata: Metadata.fromMap(map[HyperKycConstants.metadata] ?? {}),
      status: map[HyperKycConstants.status] as String?,
      statusCode: (map[HyperKycConstants.statusCode] ?? '').toString(),
      result: FaceMatchResult.fromMap(map[HyperKycConstants.result] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FaceMatchApiDetail{metadata: $metadata, status: $status, statusCode: $statusCode, result: $result}';
  }
}

/// FaceMatchResult
class FaceMatchResult {
  /// Details of Face match result
  final FaceMatchApiStructure? details;

  /// Error
  final String? error;

  /// Summary
  final Summary? summary;

  FaceMatchResult({
    this.details,
    this.error,
    this.summary,
  });

  /// Convert FaceMatchResult object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.details: this.details,
      HyperKycConstants.error: this.error,
      HyperKycConstants.summary: this.summary,
    };
  }

  /// Convert Map to FaceMatchResult object
  factory FaceMatchResult.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return FaceMatchResult();
    }
    return FaceMatchResult(
      details:
          FaceMatchApiStructure.fromMap(map[HyperKycConstants.details] ?? {}),
      error: map[HyperKycConstants.error] as String?,
      summary: Summary.fromMap(map[HyperKycConstants.summary] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FaceMatchResult{details: $details, error: $error, summary: $summary}';
  }
}

/// FaceMatchApiStructure
class FaceMatchApiStructure {
  /// Match score
  final String? matchScore;

  /// Confidence
  final String? conf;

  /// Match
  final Fieldvalue? match;

  /// to be reviewed or not
  final String? toBeReviewed;

  /// Constructor
  FaceMatchApiStructure({
    this.matchScore,
    this.conf,
    this.match,
    this.toBeReviewed,
  });

  /// Convert FaceMatchApiStructure object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.matchScore: this.matchScore,
      HyperKycConstants.conf: this.conf,
      HyperKycConstants.match: this.match,
      HyperKycConstants.toBeReviewed: this.toBeReviewed,
    };
  }

  /// Convert Map to FaceMatchApiStructure object
  factory FaceMatchApiStructure.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return FaceMatchApiStructure();
    }
    return FaceMatchApiStructure(
      matchScore: (map[HyperKycConstants.matchScore] ?? '').toString(),
      conf: (map[HyperKycConstants.conf] ?? '').toString(),
      match: Fieldvalue.fromMap(map[HyperKycConstants.match] ?? {}),
      toBeReviewed: map[HyperKycConstants.toBeReviewed] as String?,
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FaceMatchApiStructure{matchScore: $matchScore, conf: $conf, match: $match, toBeReviewed: $toBeReviewed}';
  }
}

==> 0.2.0.tar.gz: lib/hyperkyc_face_match_data.dart <==
import 'dart:convert';

import 'package:hyperkyc_flutter/hyperkyc_api_base_response.dart';

import 'hyperkyc_flutter_constants.dart';

@Deprecated('HyperKyc uses generic [ApiResult]')
/// FaceMatchDataResult contains FaceMatchData
class FaceMatchDataResult {
  /// tag of document for which this faceMatch result belongs to
  final String? tag;

  /// documentId for which this faceMatch result belongs to
  final String? documentId;

  /// List of document capture and OCR results based on no. of sides of the selected document
  final FaceMatchData? faceMatchData;

  /// Constructor
  FaceMatchDataResult({
    this.tag,
    this.documentId,
    this.faceMatchData,
  });

  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.moduleId: this.tag,
      HyperKycConstants.documentId: this.documentId,
      HyperKycConstants.faceMatchData: this.faceMatchData,
    };
  }

  factory FaceMatchDataResult.fromMap(Map<dynamic, dynamic> map) {
    return FaceMatchDataResult(
      tag: map[HyperKycConstants.moduleId] as String?,
      documentId: map[HyperKycConstants.documentId] as String?,
      faceMatchData:
      FaceMatchData.fromMap(map[HyperKycConstants.faceMatchData] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FaceMatchDataResult{tag: $tag, documentId: $documentId, faceMatchData: $faceMatchData}';
  }
}

/// FaceMatchData contains face match result
class FaceMatchData {
  /// Action - pass / manualReview / fail
  final String? action;

  /// Response headers (json string) from face match API
  final String? responseHeaders;

  /// Response body from the face match API
  final FaceMatchApiDetail? responseResult;

  /// Constructor
  FaceMatchData({
    this.action,
    this.responseHeaders,
    this.responseResult,
  });

  /// Convert FaceMatchData object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.action: this.action,
      HyperKycConstants.responseHeaders: this.responseHeaders,
      HyperKycConstants.responseResult: this.responseResult,
    };
  }

  /// Convert Map to FaceMatchData object
  factory FaceMatchData.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return FaceMatchData();
    }
    return FaceMatchData(
      action: map[HyperKycConstants.action] as String?,
      responseHeaders: map[HyperKycConstants.responseHeaders] as String?,
      responseResult: FaceMatchApiDetail.fromMap(
          jsonDecode(map[HyperKycConstants.responseResult]) ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FaceMatchData{action: $action, responseHeaders: $responseHeaders, responseResult: $responseResult}';
  }
}

/// FaceMatchApiDetail is response body from the Hyperverge face match API call
class FaceMatchApiDetail {
  /// Metadata contains data like TransactionId, RequestId, Attempts count, etc
  final Metadata? metadata;

  /// Status received after Hyperverge API call
  final String? status;

  /// StatusCode received after Hyperverge API call
  final String? statusCode;

  /// FaceMatchResult
  final FaceMatchResult? result;

  /// Constructor
  FaceMatchApiDetail({
    this.metadata,
    this.status,
    this.statusCode,
    this.result,
  });

  /// Convert FaceMatchApiDetail object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.metadata: this.metadata,
      HyperKycConstants.status: this.status,
      HyperKycConstants.statusCode: this.statusCode,
      HyperKycConstants.result: this.result,
    };
  }

  /// Convert Map to FaceMatchApiDetail object
  factory FaceMatchApiDetail.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return FaceMatchApiDetail();
    }
    return FaceMatchApiDetail(
      metadata: Metadata.fromMap(map[HyperKycConstants.metadata] ?? {}),
      status: map[HyperKycConstants.status] as String?,
      statusCode: (map[HyperKycConstants.statusCode] ?? '').toString(),
      result: FaceMatchResult.fromMap(map[HyperKycConstants.result] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FaceMatchApiDetail{metadata: $metadata, status: $status, statusCode: $statusCode, result: $result}';
  }
}

/// FaceMatchResult
class FaceMatchResult {
  /// Details of Face match result
  final FaceMatchApiStructure? details;

  /// Error
  final String? error;

  /// Summary
  final Summary? summary;

  FaceMatchResult({
    this.details,
    this.error,
    this.summary,
  });

  /// Convert FaceMatchResult object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.details: this.details,
      HyperKycConstants.error: this.error,
      HyperKycConstants.summary: this.summary,
    };
  }

  /// Convert Map to FaceMatchResult object
  factory FaceMatchResult.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return FaceMatchResult();
    }
    return FaceMatchResult(
      details:
      FaceMatchApiStructure.fromMap(map[HyperKycConstants.details] ?? {}),
      error: map[HyperKycConstants.error] as String?,
      summary: Summary.fromMap(map[HyperKycConstants.summary] ?? {}),
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FaceMatchResult{details: $details, error: $error, summary: $summary}';
  }
}

/// FaceMatchApiStructure
class FaceMatchApiStructure {
  /// Match score
  final String? matchScore;

  /// Confidence
  final String? conf;

  /// Match
  final Fieldvalue? match;

  /// to be reviewed or not
  final String? toBeReviewed;

  /// Constructor
  FaceMatchApiStructure({
    this.matchScore,
    this.conf,
    this.match,
    this.toBeReviewed,
  });

  /// Convert FaceMatchApiStructure object to Map
  Map<String, dynamic> toMap() {
    return {
      HyperKycConstants.matchScore: this.matchScore,
      HyperKycConstants.conf: this.conf,
      HyperKycConstants.match: this.match,
      HyperKycConstants.toBeReviewed: this.toBeReviewed,
    };
  }

  /// Convert Map to FaceMatchApiStructure object
  factory FaceMatchApiStructure.fromMap(Map<dynamic, dynamic> map) {
    if (map.isEmpty) {
      return FaceMatchApiStructure();
    }
    return FaceMatchApiStructure(
      matchScore: (map[HyperKycConstants.matchScore] ?? '').toString(),
      conf: (map[HyperKycConstants.conf] ?? '').toString(),
      match: Fieldvalue.fromMap(map[HyperKycConstants.match] ?? {}),
      toBeReviewed: map[HyperKycConstants.toBeReviewed] as String?,
    );
  }

  /// Overriden toString() method
  @override
  String toString() {
    return 'FaceMatchApiStructure{matchScore: $matchScore, conf: $conf, match: $match, toBeReviewed: $toBeReviewed}';
  }
}
